@@ -2,7 +2,7 @@
 from django.db import models
 from django.template.defaultfilters import slugify
 
-from django_roa import Model, Manager
+from django_roa import Model
 
 class RemotePage(Model):
     title = models.CharField(max_length=50, blank=True, null=True)
@@ -62,7 +62,7 @@ class RemotePageWithCustomSlug(Model):
     def __unicode__(self):
         return u'%s (%s)' % (self.title, self.id)
 
-    def save(self, force_insert=False, force_update=False):
+    def save(self, force_insert=False, force_update=False, using=None):
         if not self.slug:
             self.slug = slugify(self.title)
         super(RemotePageWithCustomSlug, self).save(force_insert, force_update)
@@ -82,7 +82,7 @@ class RemotePageWithOverriddenUrls(Model):
     def __unicode__(self):
         return u'%s (%s)' % (self.title, self.id)
 
-    def save(self, force_insert=False, force_update=False):
+    def save(self, force_insert=False, force_update=False, using=None):
         if not self.slug:
             self.slug = slugify(self.title)
         super(RemotePageWithOverriddenUrls, self).save(force_insert, force_update)
@@ -92,10 +92,23 @@ class RemotePageWithOverriddenUrls(Model):
         return u'' # overridden by settings
 
 
+class RemotePageWithRelationsThrough(Model):
+    title = models.CharField(max_length=50)
+    remote_page_with_relations = models.ForeignKey("RemotePageWithRelations", blank=True, null=True)
+    remote_page_with_many_fields = models.ForeignKey("RemotePageWithManyFields", blank=True, null=True)
+
+    def __unicode__(self):
+        return u'%s (%s)' % (self.title, self.id)
+    
+    @staticmethod
+    def get_resource_url_list():
+        return u'http://127.0.0.1:8081/django_roa_server/remotepagewithrelationsthrough/'
+
+
 class RemotePageWithRelations(Model):
     title = models.CharField(max_length=50)
     remote_page = models.ForeignKey(RemotePage, blank=True, null=True)
-    remote_page_fields = models.ManyToManyField(RemotePageWithManyFields, blank=True, null=True)
+    remote_page_fields = models.ManyToManyField(RemotePageWithManyFields, through=RemotePageWithRelationsThrough, blank=True, null=True)
 
     def __unicode__(self):
         return u'%s (%s)' % (self.title, self.id)
