@@ -179,7 +179,7 @@ class Mimer(object):
             for mime in mimes:
                 if ctype.startswith(mime):
                     return loadee
-
+                    
     def content_type(self):
         """
         Returns the content type of the request in all cases where it is
@@ -193,7 +193,6 @@ class Mimer(object):
             return None
         
         return ctype
-        
 
     def translate(self):
         """
@@ -214,15 +213,18 @@ class Mimer(object):
         if not self.is_multipart() and ctype:
             loadee = self.loader_for_type(ctype)
             
-            try:
-                self.request.data = loadee(self.request.raw_post_data)
-                    
-                # Reset both POST and PUT from request, as its
-                # misleading having their presence around.
-                self.request.POST = self.request.PUT = dict()
-            except (TypeError, ValueError):
-                # This also catches if loadee is None.
-                raise MimerDataException
+            if loadee:
+                try:
+                    self.request.data = loadee(self.request.raw_post_data)
+                        
+                    # Reset both POST and PUT from request, as its
+                    # misleading having their presence around.
+                    self.request.POST = self.request.PUT = dict()
+                except (TypeError, ValueError):
+                    # This also catches if loadee is None.
+                    raise MimerDataException
+            else:
+                self.request.data = None
 
         return self.request
                 
@@ -298,12 +300,13 @@ def send_consumer_mail(consumer):
     except AttributeError:
         sender = settings.DEFAULT_FROM_EMAIL
 
-    send_mail(_(subject), body, sender, [consumer.user.email], fail_silently=True)
+    if consumer.user:
+        send_mail(_(subject), body, sender, [consumer.user.email], fail_silently=True)
 
     if consumer.status == 'pending' and len(settings.ADMINS):
         mail_admins(_(subject), body, fail_silently=True)
 
-    if settings.DEBUG:
+    if settings.DEBUG and consumer.user:
         print "Mail being sent, to=%s" % consumer.user.email
         print "Subject: %s" % _(subject)
         print body
